#Finechem version 1.0

finechem.apply.models <- function (Input, Model.CED, Model.GWP, Model.EI, Norm, Factors, Output){
  
  size <- dim(Input)[1]
  col <- c(0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0)
  df <- cbind(col)
  for (i in 2:size){
    df <- cbind(df,col)
    df.CED <- df
    df.GWP <- df
    df.EI <- df

  }
  for (i in 1:size){
    for (j in 1:30){
      Input.norm.CED <- cbind((Input[i,] - Norm[,1] ) / Norm[,2])
      Input.factor.CED <- c(0,0,0,0,0,0,0,0) 
      for (faci in 1:8){
      Input.factor.CED[faci] <- sum(Input.norm.CED * Finechem.factors[,faci])
      }
      Prediction <- predict (Model.CED[[j]], Input.factor.CED, type="raw")
      un.pred <- (Prediction * Output[2, 1] ) + Output[1, 1]
      df.CED[j,i] <- un.pred


      Input.norm.GWP <- cbind((Input[i,] - Norm[,3] ) / Norm[,4])
      Input.factor.GWP <- c(0,0,0,0,0,0,0,0) 
      for (faci in 1:8){
      Input.factor.GWP[faci] <- sum(Input.norm.GWP * Finechem.factors[,faci])
      }
      Prediction <- predict (Model.GWP[[j]], Input.factor.GWP, type="raw")
      un.pred <- (Prediction * Output[2, 2] ) + Output[1, 2]
      df.GWP[j,i] <- un.pred


      Input.norm.EI <- cbind((Input[i,] - Norm[,5] ) / Norm[,6])
      Input.factor.EI <- c(0,0,0,0,0,0) 
      for (faci in 1:6){
      Input.factor.EI[faci] <- sum(Input.norm.EI * Finechem.factors[,faci+8])
      }
      Prediction <- predict (Model.EI[[j]], Input.factor.EI, type="raw")
      un.pred <- (Prediction * Output[2, 3] ) + Output[1, 3]
      df.EI[j,i] <- un.pred



    } 
  }
 
  p <- c(0,0,0,0,0,0)
  means <- cbind (p)
  for (i in 2:size){
    means <- cbind(means,p)
  }

  for (k in 1:size){
    means [1,k] <- mean(df.CED[,k])
    means [2,k] <- sd(df.CED[,k])

    means [3,k] <- mean(df.GWP[,k])
    means [4,k] <- sd(df.GWP[,k])

    means [5,k] <- mean(df.EI[,k])
    means [6,k] <- sd(df.EI[,k])


  }



  means
}




Finechem.input <- read.csv("Finechem\\Finechem_input.csv")
Finechem.normalization <- read.csv("Finechem\\Finechem_normalization.csv")
Finechem.factors <- read.csv("Finechem\\Finechem_factors.csv")
Finechem.outputs <- read.csv("Finechem\\Finechem_outputs.csv")


	
FC1 <- finechem.apply.models (Finechem.input, FineChem.CED, FineChem.GWP, FineChem.EI, Finechem.normalization, Finechem.factors, Finechem.outputs)

molnames <- paste ("Molecule_",1,sep="")
for (l in 2:dim(Finechem.input)[1]) {  
    colname <- paste ("Molecule_",l,sep="")
    molnames <- c(molnames,colname)

}
Res <- cbind (molnames, round(FC1[1,],digits = 2),  round(FC1[2,],digits = 2),  round(FC1[3,],digits = 3),  round(FC1[4,],digits = 3),  round(FC1[5,],digits = 4),  round(FC1[6,],digits = 4))
Res.Names <- c("Molecule","CED_Prediction_Mean","CED_Prediction_st_dev","GWP_Prediction_Mean","GWP_Prediction_st_dev","EI99_Prediction_Mean","EI99_Prediction_st_dev")
Res <- rbind(Res.Names,Res)

write.csv(Res,file="Finechem\\Finechem.prediction.csv",row.names=FALSE)


print("  Finechem tool 1.0")
print("Calculation completed")
print("---------------------")

print("Please read the user guide if you are unfamiliar with the Finechem tool.")
print("The input limits for this version are:")
print("Molecular Weight between 30 and 1400 g/mol")
print("Number of functional groups between 0 and 30")


# Check inputs 

size.I <- dim(Finechem.input)[1]

for (i in 2:size.I){
  if (Finechem.input[i,1] > 1400) {print("WARNING: Molecular Weight out of bounds. Models extrapolating - results will be unreliable!")}
  if (Finechem.input[i,1] < 30) {print("WARNING: Molecular Weight out of bounds. Models extrapolating - results will be unreliable!")}
  if (Finechem.input[i,8] < 0) {print("WARNING: Number of functional groups out of bounds. Models extrapolating - results will be unreliable!")}
  if (Finechem.input[i,8] > 30) {print("WARNING: Number of functional groups out of bounds. Models extrapolating - results will be unreliable!")}

}




